@@ -3,7 +3,7 @@ import pandas as pd
 from dateutil.parser import parse
 
 from .utils import fetch_first, fetch_all_pages
-from .data import layer, covid19, dataset, daily_mobility_matrix, population, zone_movements
+from .data import geolayer, covid19, dataset, daily_mobility_matrix, population, zone_movements
 
 
 def list_layers():
@@ -42,7 +42,7 @@ def download_layer(layer, output_file, plot=False, no_save=False):
         output_file = layer+'.geojson'
 
     print(f'Dowloading layer {layer}')
-    featureCollection = layer(layer, print_url=True)
+    featureCollection = geolayer(layer, print_url=True)
 
     if not no_save:
         print(f'Saving layer to file: {output_file}')
@@ -224,9 +224,12 @@ def describe_daily_mobility_matrix(provenance=False):
     print("Example document:\n"+json.dumps(example, indent=4))
 
 
-def download_daily_mobility_matrix(source_layer, target_layer, date, output_file, output_format='csv', source=None, target=None):
-    print(f'Dowloading mobility matrix for source_layer={source_layer} target_layer={target_layer} date={date}')
-    data = daily_mobility_matrix(source_layer, target_layer, date, fmt='records', print_url=True, source=source, target=target)
+def download_daily_mobility_matrix(source_layer, target_layer, output_file, start_date=None, end_date=None, output_format='csv', source=None, target=None):
+    print(f'Dowloading mobility matrix for source_layer={source_layer} target_layer={target_layer}')
+    data = daily_mobility_matrix(source_layer, target_layer, 
+                                 start_date=start_date, end_date=end_date, 
+                                 source=source, target=target,
+                                 fmt='records', print_url=True)
     if output_format == 'csv':
         df = pd.DataFrame(data)
         df.to_csv(output_file, index=False)
