@@ -4,14 +4,19 @@ from datetime import datetime, timedelta
 from .utils import fetch_first, fetch_all_pages, parse_date, date_rfc1123
 
 
-def layer(layer, print_url=False):
+def geolayer(layer, print_url=False):
     filters = {
         'layer': layer
     }
     data = fetch_all_pages('layers', filters, print_url=print_url)
+
     featureCollection = {
         "type": "FeatureCollection",
-        "features": [doc['feat'] for doc in data],
+        "features": [{
+            'id': doc['id'],
+            'centroid': doc['centroid'],
+            **doc['feat'],
+        } for doc in data],
     }
     return featureCollection
 
@@ -49,12 +54,17 @@ def dataset(ev, start_date=None, end_date=None, fmt='csv', print_url=False):
     return data
 
 
-def daily_mobility_matrix(source_layer, target_layer, date, source=None, target=None, fmt='csv', print_url=False):
+def daily_mobility_matrix(source_layer, target_layer, start_date=None, end_date=None, source=None, target=None, fmt='csv', print_url=False):
     filters = {
-        'date': date,
         'source_layer': source_layer,
         'target_layer': target_layer,
     }
+    if start_date and end_date:
+        filters['date'] = {'$gte': start_date, '$lte': end_date}
+    elif start_date:
+        filters['date'] = {'$gte': start_date}
+    elif end_date:
+        filters['date'] = {'$lte': end_date}
     if source:
         filters['source'] = source
     if target:
