@@ -99,9 +99,12 @@ CONFIG = {
                 "argparse": {
                     "--source-layer": {"required": True, "dest": "source_layer", "type": str, "help": "", },
                     "--target-layer": {"required": True, "dest": "target_layer", "type": str, "help": "", },
-                    "--date": {"required": True, "type": str, "help": "", },
+                    "--source": {"required": False, "type": str, "help": "", },
+                    "--target": {"required": False, "type": str, "help": "", },
                     "--output-file": {"required": True, "dest": "output_file", "type": str, "help": "", },
                     "--output-format": {"required": False, "dest": "output_format", "default": "csv", "type": str, "help": "", },
+                    "--start-date": {"dest": "start_date", "required": False, "type": str, "help": "", },
+                    "--end-date": {"dest": "end_date", "required": False, "type": str, "help": "", },
                 },
             },
         },
@@ -182,7 +185,7 @@ examples:
     # Origin-destination daily mobility (from MITMA)
     flowmaps-data daily_mobility_matrix list
     flowmaps-data daily_mobility_matrix describe
-    flowmaps-data daily_mobility_matrix download --source-layer cnig_provincias --target-layer cnig_provincias --date 2020-10-10 --output-file out.csv
+    flowmaps-data daily_mobility_matrix download --source-layer cnig_provincias --target-layer cnig_provincias --start-date 2020-10-10 --end-date 2020-10-16 --output-file out.csv
 
     # Daily zone movements (from MITMA)
     flowmaps-data zone_movements list
